package ca.svarb.jyacl;

/** 
 * Extracts the attribute name from a getter method name.
 * Getter method name must begin with "get" or "is".
 * Attribute name will be portion of method name
 * after the "get" or "is"
 */
public class Attribute {

	private String name;

	/**
	 * Constructs this attribute from the methodName.
	 * @param methodName
	 * @throws IllegalStateException If not called with a method name that 
	 * starts with "get" or "is".
	 */
	public Attribute(String methodName) {
		this.name = getAttributeNameFromGetterMethod(methodName);
	}

	public String getName() {
		return name;
	}

    private String getAttributeNameFromGetterMethod(String methodName) {
        boolean startsWithGet = methodName.startsWith("get");
        boolean startsWithIs = methodName.startsWith("is");
        if ( !startsWithGet && !startsWithIs ) {
            throw new IllegalArgumentException("Attribute name can only be determined from interface methods starting with \"get\" or \"is\".  Cannot support method named \""+methodName+"\"");
        }
        String attributeName= startsWithGet ? methodName.substring(3) : methodName.substring(2);
        return attributeName.toLowerCase();
    }
}
