package ca.svarb.jyacl;

import java.util.Collection;

/**
 * Represents a command line Usage statement.<p>
 * 
 * A usage is composed of a name, options that comprise that usage,
 * and a Class that may be used to represent the usage.<p>
 * 
 * For example, in the following command there are two usage
 * statements:
 * 
 * <pre>
 *      --create --name=VALUE --id=INTEGER
 *   OR --list --id=INTEGER
 * </pre>
 * 
 * The first usage is identified by the name "create", the second by the
 * name "list".  The create usage has two options "--name" and "--id".
 * The list usage has one option "--id".  It is valid for a usage
 * to have no options.
 * 
 * It is also valid for a usage to be unnamed.
 * 
 * @author bmodi
 *
 */
public class Usage {

	private Collection<CliOption> cliOptions;
	private String name;
	private Class<?> returnType;

	/**
	 * Create an unnamed usage statement with the given options.
	 * @param cliOptions
	 */
	public Usage(Collection<CliOption> cliOptions) {
		this.cliOptions=cliOptions;
	}

	public Usage(String name, Class<?> returnType, Collection<CliOption> usageOptions) {
		this.name=name;
		this.cliOptions=usageOptions;
		this.returnType = returnType;
	}

	public Collection<CliOption> getCliOptions() {
		return this.cliOptions;
	}

	public Class<?> getReturnType() {
		return returnType;
	}

	public String getName() {
		return name;
	}
	
	public String toString() {
		return CliOption.CLI_OPTION_PREFIX+name;
	}
}
